import { Component, OnInit } from "@angular/core";
import { CapabilityLauncherService } from "./services/capability-launcher.service";
import { CapabilityRequest } from "./model/capability-request";
import { CapabilityExecution } from "./model/capability-execution";

@Component({
  selector: "app-workspaces",
  templateUrl: "./workspaces.component.html",
  styleUrls: ["./workspaces.component.scss"],
})
export class WorkspacesComponent implements OnInit {
  public capabilityRequests: Array<CapabilityRequest> = [];
  public capabilityExecutions: Array<CapabilityExecution> = [];

  public productLocator: string;
  public userEmail: string;

  constructor(private capabilityLauncher: CapabilityLauncherService) {
    // this is the famous 394 MB 13B-014 execblock, a useful smallish test
    this.productLocator = "uid://evla/image/3d3db489-9331-4e61-aa80-002bc2989b1e";

    this.userEmail = null;
  }

  ngOnInit(): void {}

  /**
   * OnClick method that creates a capability request for the null capability and submits it
   */
  nullButtonOnClick(): void {
    this.launchCapability("null", { arguments: "-g" });
  }

  /**
   * OnClick method that creates a capability request for the test_download capability and submits it
   */
  downloadButtonOnClick(): void {
    this.launchCapability("test_download", {
      product_locator: this.productLocator,
      user_email: this.userEmail,
    });
  }

  /**
   * method that sets the user input Science Product Locator for the download capability
   * @param spl the Science Product Locator to download
   */
  setProductLocator(spl: string): void {
    this.productLocator = spl;
  }

  /**
   * method to set the user email for notifications
   * @param email user specified email
   */
  setUserEmail(email: string): void {
    this.userEmail = email;
  }

  /**
   * Method that uses the capabilityLauncher service to launch a capability
   * @param capabilityName  Name of capability
   * @param parameters      Parameters of capability request
   * @param email           User email for notifications (Optional)
   */
  launchCapability(capabilityName: string, parameters: any): void {
    // Create capability request
    this.capabilityLauncher.createRequest(capabilityName, parameters).subscribe(
      (requestResponse) => {
        this.capabilityRequests.push(requestResponse);
        if (requestResponse.id) {
          // Capability request created; ID found
          // Submit capability request
          this.capabilityLauncher.submit(requestResponse.id).subscribe(
            (submitResponse) => {
              this.capabilityExecutions.push(submitResponse);
            },
            (error) => {
              console.log(error);
            },
          );
        }
      },
      (error) => {
        console.log(error);
      },
    );
  }
}
